@@ -220,13 +220,17 @@ struct _GnmFuncEvalInfo {
 	GnmExprEvalFlags flags;
 };
 
+GnmFunc const *gnm_eval_info_get_func (GnmFuncEvalInfo const *ei);
+int gnm_eval_info_get_arg_count (GnmFuncEvalInfo const *ei);
+
+
 GType       gnm_func_get_type        (void);
 void	    gnm_func_free	     (GnmFunc *func);
 GnmFunc	   *gnm_func_ref	     (GnmFunc *func);
 void	    gnm_func_unref	     (GnmFunc *func);
 void        gnm_func_load_if_stub    (GnmFunc *func);
 void	    gnm_func_load_stub	     (GnmFunc *fn_def);
-char const *gnm_func_get_name	     (GnmFunc const *fn_def,
+char const *gnm_func_get_name	     (GnmFunc const *func,
 				      gboolean localized);
 gpointer    gnm_func_get_user_data   (GnmFunc const *func);
 void        gnm_func_set_user_data   (GnmFunc *func, gpointer user_data);
@@ -251,13 +255,13 @@ void        gnm_func_upgrade_placeholder
 
 /* TODO */
 char const *gnm_func_get_description (GnmFunc const *fn_def);
-void        function_def_count_args    (GnmFunc const *fn_def,
+void        gnm_func_count_args    (GnmFunc const *fn_def,
                                         gint *min, int *max);
-char        function_def_get_arg_type  (GnmFunc const *fn_def,
+char        gnm_func_get_arg_type  (GnmFunc const *fn_def,
                                         gint arg_idx);
-char const *function_def_get_arg_type_string  (GnmFunc const *fn_def,
+char const *gnm_func_get_arg_type_string  (GnmFunc const *fn_def,
                                         gint arg_idx);
-char       *function_def_get_arg_name  (GnmFunc const *fn_def,
+char       *gnm_func_get_arg_name  (GnmFunc const *fn_def,
                                         guint arg_idx);
 char const *gnm_func_get_arg_description (GnmFunc const *fn_def,
                                         guint arg_idx);
